<?php
/**
 * Plugin Messages (addon for plugin Adm_redacteurs)
 * Version  : 1.1 (2017/10/23)
 * Compatibility : Guppy v5.0+ et Adm_redacteurs v6.8+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once MESSAGES_HELPERS_PATH.'/manage_messages_helper.php';

class Manage_messages_receveid_helper extends Manage_messages_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri

    protected $_doc_infos = array('name' => 'messages', 'type' => 'messages'); // Tableau contenant les informations du document (nom, type)
    protected $_writer_rights = array(); // Droits du rédacteur
    //
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights)
    {
        parent :: __construct($writer_rights);
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }

	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        return search();
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @access public
     * @return string titre de la page
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['manage_messages_receveid']);
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _get_records()
    {
        $doc_ids = empty($this -> _params['msg_received_ids']) ? array() : explode('-', $this -> _params['msg_received_ids']);        
        $author_ids = (empty($this -> _params['author_ids']) && $this -> _params['author_ids'] !== '0') ? array() : explode('-', $this -> _params['author_ids']);        

        // Messages reçus uniquement
        $records = $this -> CI -> writer_messages_model -> get(array('receiver_id' => array($this -> _writer_rights['id']), 'id' => $doc_ids, 'author_id' => $author_ids), $this -> _params['sort']);
               
        return $records;
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            parent :: _set_data_table_header_for_id(),
            array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['author']), 'from'), 'attrs' => array('id' => 'rfrom', 'align'=> 'left', 'style' => 'width:15%')),
			parent :: _set_data_table_header_for_description($this -> _lang['title']),
            array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['date']), 'time'), 'attrs' => array('id' => 'rtime', 'align'=> 'center', 'style' => 'width:15%')),
            array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['state']), 'mode'), 'attrs' => array('id' => 'rmode', 'align'=> 'center', 'style' => 'width:15%')),
            parent :: _set_data_table_header_for_commands(),
		);

        return $headers;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {
    	$cells = array(
            parent :: _set_data_table_cell_for_id($record),
            array('contents' => $this -> _add_contents_for_td_author($record), 'attrs' => array('align' => 'left')),
            parent :: _set_data_table_cell_for_description($record),
            array('contents' => $this -> _add_contents_for_td_date($record), 'attrs' => array('align' => 'center')),
            array('contents' => $this -> _add_contents_for_td_state($record), 'attrs' => array('align' => 'center')),
            parent :: _set_data_table_cell_for_commands($record),
    	);
        
        return $cells;
    }

	// --------------------------------------------------------------------

} //End of Class